%define module	nose

Summary:	Unittest-based testing framework for Python
Name:		python-%{module}
Version:	1.3.7
Release:	%mkrel 4
Source0:	https://pypi.python.org/packages/source/n/nose/%{module}-%{version}.tar.gz
License:	LGPLv2+
Group:		Development/Python
Url:		http://readthedocs.org/docs/nose/
BuildArch:	noarch
BuildRequires:	python-sphinx >= 0.6.0
BuildRequires:	pkgconfig(python)
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-coverage >= 3.4-1
BuildRequires:	python-coverage >= 3.4-1
BuildRequires:	dos2unix
BuildRequires:	python-setuptools
BuildRequires:	python3-setuptools
Requires:	python-setuptools

%description
nose extends the test loading and running features of unittest, making it easier
to write, find and run tests.

By default, nose will run tests in files or directories under the current
working directory whose names include "test" or "Test" at a word boundary (like
"test_this" or "functional_test" or "TestClass" but not "libtest"). Test output
is similar to that of unittest, but also includes captured stdout output from
failing tests, for easy print-style debugging.

These features, and many more, are customizable through the use of plugins.
Plugins included with nose provide support for doctest, code coverage and
profiling, flexible attribute-based test selection, output capture and more.

%package docs
Summary:	Nose Documentation
Group:		Documentation
BuildRequires:	python-sphinx
Requires:	python-nose

%description docs
Documentation for Nose

%package -n python3-%{module}
Summary:	Discovery-based unittest extension for Python3
Group:		Development/Python
Requires:	python3-setuptools

%description -n python3-%{module}
nose extends the test loading and running features of unittest, making it easier
to write, find and run tests.

By default, nose will run tests in files or directories under the current
working directory whose names include "test" or "Test" at a word boundary (like
"test_this" or "functional_test" or "TestClass" but not "libtest"). Test output
is similar to that of unittest, but also includes captured stdout output from
failing tests, for easy print-style debugging.

This package installs the nose module and nosetests3 program that can discover
python3 unittests.

%prep
%setup -q -n %{module}-%{version}
dos2unix examples/attrib_plugin.py

cp -a . %{py3dir}

%build
%py2_build

pushd %{py3dir}
%py3_build
popd

%install
# Must do the python3 install first because the scripts in /usr/bin are
# overwritten with every setup.py install (and we want the python2 version
# to be the default for now).
pushd %{py3dir}
%py3_install
rm %{buildroot}%{_bindir}/nosetests
mkdir -m 0755 -p %{buildroot}%{_mandir}/man1/
mv %{buildroot}%{_prefix}/man/man1/nosetests.1 %{buildroot}%{_mandir}/man1/nosetests-%{python3_version}.1
%__lzma -z %{buildroot}%{_mandir}/man1/nosetests-%{python3_version}.1 
popd

%define install_parameters --install-data=%{_datadir}
%py2_install %{install_parameters}
%__lzma -z %{buildroot}%{_mandir}/man1/nosetests.1 

pushd doc
make html
rm -rf .build/html/.buildinfo .build/html/_sources
mv .build/html ..
rm -rf .build
popd
cp -a doc reST
rm -rf reST/.static reST/.templates

%check
# Various selftests fail on our build system; skip them for now using "-e"
%{__python2} selftest.py -e test_multiprocessing -e test_coverage_plugin
exit 0 # disable python3 testsuite
pushd %{py3dir}
export PYTHONPATH=`pwd`/build/lib
%{__python3} setup.py build_tests
%{__python3} selftest.py -e test_multiprocessing -e test_coverage_plugin
popd

%files 
%doc AUTHORS CHANGELOG lgpl.txt NEWS README.txt
%{_bindir}/nosetests
%{_bindir}/nosetests-%{python2_version}
%{_mandir}/man1/nosetests.*
%{python2_sitelib}/nose*

%files -n python3-%{module}
%doc AUTHORS CHANGELOG lgpl.txt NEWS README.txt
%{_bindir}/nosetests-%{python3_version}
%{_mandir}/man1/nosetests-%{python3_version}.*
%{python3_sitelib}/nose*

%files docs
%doc reST examples
%doc html


%changelog
* Wed May 25 2016 daviddavid <daviddavid> 1.3.7-4.mga6
+ Revision: 1018437
- fix testsuite build against new python-coverage 4.1 adding 'test_coverage_plugin'
- use new python macros

* Fri Feb 19 2016 umeabot <umeabot> 1.3.7-3.mga6
+ Revision: 970494
- Mageia 6 Mass Rebuild

* Wed Oct 07 2015 tv <tv> 1.3.7-2.mga6
+ Revision: 886947
- disable python3 with python 3.5 like FC did
- rebuild for python 3.5

* Fri Aug 28 2015 philippem <philippem> 1.3.7-1.mga6
+ Revision: 870570
- update to 1.3.7

* Wed Oct 15 2014 umeabot <umeabot> 1.3.4-4.mga5
+ Revision: 742180
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.3.4-3.mga5
+ Revision: 729153
- rebuild for missing pythoneggs deps

  + umeabot <umeabot>
    - Mageia 5 Mass Rebuild

* Sat Aug 30 2014 philippem <philippem> 1.3.4-1.mga5
+ Revision: 669684
- update to 1.3.4

* Sun Jun 01 2014 pterjan <pterjan> 1.3.3-1.mga5
+ Revision: 629905
- Drop no longer needed line
- 1.3.3
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 1.3.0-4.mga4
+ Revision: 543882
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.3.0-3.mga4
+ Revision: 498968
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Aug 25 2013 philippem <philippem> 1.3.0-2.mga4
+ Revision: 471676
- Various selftests fail on our build system; skip them for now

* Mon Jul 01 2013 philippem <philippem> 1.3.0-1.mga4
+ Revision: 449480
- update to 1.3.0

* Sun Jan 13 2013 umeabot <umeabot> 1.0.0-5.mga3
+ Revision: 379162
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 31 2011 dmorgan <dmorgan> 1.0.0-4.mga1
+ Revision: 45344
- Rebuild against python 2.7

  + pterjan <pterjan>
    - Rebuild for python 2.7

* Thu Jan 13 2011 ahmad <ahmad> 1.0.0-2.mga1
+ Revision: 8367
- drop the old %%py_requires macro and add BR python-devel
- imported package python-nose


* Thu Dec 16 2010 Lev Givon <lev@mandriva.org> 1.0.0-1mdv2011.0
+ Revision: 622412
- Update to 1.0.0.

* Fri Oct 29 2010 Michael Scherer <misc@mandriva.org> 0.11.4-2mdv2011.0
+ Revision: 590015
- rebuild for python 2.7

* Mon Jul 12 2010 Lev Givon <lev@mandriva.org> 0.11.4-1mdv2011.0
+ Revision: 551261
- Update to 0.11.4.

* Mon Mar 08 2010 Lev Givon <lev@mandriva.org> 0.11.3-1mdv2010.1
+ Revision: 515634
- Update to 0.11.3.

* Wed Dec 09 2009 Lev Givon <lev@mandriva.org> 0.11.1-1mdv2010.1
+ Revision: 475619
- Update to 0.11.1.

* Tue Jun 23 2009 Lev Givon <lev@mandriva.org> 0.11.0-1mdv2010.0
+ Revision: 388721
- Update to 0.11.0.

* Wed May 06 2009 Lev Givon <lev@mandriva.org> 0.10.4-3mdv2010.0
+ Revision: 372562
- Make package own its own module directory in %%py_sitedir.

* Fri Dec 26 2008 Funda Wang <fwang@mandriva.org> 0.10.4-2mdv2009.1
+ Revision: 319375
- rebuld for new python

* Tue Dec 16 2008 Lev Givon <lev@mandriva.org> 0.10.4-1mdv2009.1
+ Revision: 314963
- Update to 0.10.4.

* Wed Jun 18 2008 Lev Givon <lev@mandriva.org> 0.10.3-1mdv2009.0
+ Revision: 225981
- Update to 0.10.3.

* Fri May 30 2008 Lev Givon <lev@mandriva.org> 0.10.2-1mdv2009.0
+ Revision: 213479
- Update to 0.10.2.

* Tue Feb 19 2008 Lev Givon <lev@mandriva.org> 0.10.1-2mdv2008.1
+ Revision: 172897
- import python-nose


* Mon Feb 18 2008 Lev Givon <lev@mandriva.org> 0.10.1-1mdv2008.0
- Initial Mandriva package.
